@@ -1,10 +1,9 @@
 """
-Find the conf.py files specificed in sources
+Find the conf.py files specified in sources
 """
 # Import python libs
 import importlib
 import copy
-import secrets
 import os
 
 
@@ -25,8 +24,8 @@ def load(hub, sources, dyne_names, cli):
     Look over the sources list and find the correct conf.py files
     """
     # Dynamic names
-    # First gather the defined sources, they are the autoritative ones
-    # Then ditect what the dynamic names are in the source
+    # First gather the defined sources, they are the authoritative ones
+    # Then detect what the dynamic names are in the source
     # Merged the sources dyne names with any passed dyne names
     # Load up and extend the raw with all of the dynamic names
     raw = {}
@@ -47,15 +46,31 @@ def load(hub, sources, dyne_names, cli):
         if name in dyne:
             if name not in raw:
                 raw[name] = {"CONFIG": {}, "CLI_CONFIG": {}}
+            if "CONFIG" in dyne[name]:
+                config_draw = {}
+                for key, val in dyne[name]["CONFIG"].items():
+                    new_dyne = val.get("dyne")
+                    if new_dyne == "__cli__":
+                        new_dyne = cli
+                    if new_dyne:
+                        val["source"] = new_dyne
+                        config_draw[key] = val
+                        if (
+                            key in dyne[name]["CLI_CONFIG"]
+                            and "dyne" not in dyne[name]["CLI_CONFIG"][key]
+                        ):
+                            dyne[name]["CLI_CONFIG"][key]["dyne"] = new_dyne
+                hub.pop.dicts.update(raw[cli]["CONFIG"], config_draw)
             if "CLI_CONFIG" in dyne[name]:
-                draw = {}
                 cli_draw = {}
                 for key, val in dyne[name]["CLI_CONFIG"].items():
-                    if val.get("dyne"):
-                        val["source"] = name
+                    new_dyne = val.get("dyne")
+                    if new_dyne == "__cli__":
+                        new_dyne = cli
+                    if new_dyne:
+                        val["source"] = new_dyne
                         cli_draw[key] = val
                 hub.pop.dicts.update(raw[cli]["CLI_CONFIG"], cli_draw)
-    raw = hub.config.inject.add(cli, raw)
     return raw
 
 
