@@ -43,7 +43,7 @@ def load(hub, paths, loader, includes=True):
         add.extend(glob.glob(fn))
     paths.extend(add)
     for fn in paths:
-        fn_data = getattr(hub, f"config.render.{loader}.load")(fn)
+        fn_data = hub.config.render.init.load_file(loader, fn)
         if includes:
             fn_data = hub.config.file.init.proc_include(fn, fn_data, loader)
         hub.pop.dicts.update(opts, fn_data)
